List:Commits« Previous MessageNext Message »
From:omer Date:March 20 2007 10:44pm
Subject:bk commit into 5.1 tree (omer:1.2510)
View as plain text  
Below is the list of changes that have just been committed into a local
5.1 repository of omer. When omer does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet@stripped, 2007-03-20 14:43:58-07:00, omer@stripped +1 -0
  Merge linux.site:/home/omer/source/bld50_0320
  into  linux.site:/home/omer/source/bld51_0319
  MERGE: 1.1810.2373.170

  mysql-test/mysql-test-run.pl@stripped, 2007-03-20 14:43:52-07:00, omer@stripped +0 -0
    Auto merged
    MERGE: 1.30.49.67

# This is a BitKeeper patch.  What follows are the unified diffs for the
# set of deltas contained in the patch.  The rest of the patch, the part
# that BitKeeper cares about, is below these diffs.
# User:	omer
# Host:	linux.site
# Root:	/home/omer/source/bld51_0319/RESYNC

--- 1.284/mysql-test/mysql-test-run.pl	2007-03-20 14:44:10 -07:00
+++ 1.285/mysql-test/mysql-test-run.pl	2007-03-20 14:44:10 -07:00
@@ -3664,8 +3664,13 @@
 
   if ( $mysql_version_id >= 50036)
   {
     # Prevent the started mysqld to access files outside of vardir
     mtr_add_arg($args, "%s--secure-file-priv=%s", $prefix, $opt_vardir);
+    if ( $opt_suite ne "main" )
+    {
+       mtr_add_arg($args, "%s--secure-file-priv=%s", $prefix, $glob_mysql_test_dir);
+    }
+
   }
 
   if ( $mysql_version_id >= 50000 )
@@ -3664,8 +3664,13 @@
   if ( $mysql_version_id >= 50036)
   {
-    # Prevent the started mysqld to access files outside of vardir
+    # Prevent the started mysqld to access files outside of vardir/mysql-test
     mtr_add_arg($args, "%s--secure-file-priv=%s", $prefix, $opt_vardir);

Thread
bk commit into 5.1 tree (omer:1.2510)omer20 Mar